sorl-thumbnail version 10.12-beta2
==================================

Thumbnails for Django. Totally rewritten.

Features at a glance
--------------------
- Storage support
- Pluggable Engine support (PIL, pgmagick)
- Pluggable Key Value Store support (redis, cached db)
- Pluggable Backend support
- Dummy generation (no you dont have to download the production site's 666GB of
  images to develop locally anymore).
- Flexible, simple syntax, generates no html
- ImageField for model that deletes thumbnails
- CSS style cropping options
- Margin calculation for vertical positioning

Read more in `the half assed documentation so far <http://thumbnail.sorl.net/>`_

